import { Button, Card, notification, Col, Row, Popconfirm } from 'antd';
import React, { useState, useEffect } from 'react';
import classnames from 'classnames'
import styles from '../SchemeConfig.less'
import {
    GetAllConfig, deleteConfig,unbindSchemeBaseMap
} from '@/services/webConfig/api';
import {
    CloseOutlined, PlusOutlined
} from '@ant-design/icons';
import AddModal from './AddModal'
const VectorData = props => {
    const [treeLoading, setTreeLoading] = useState(false);// 弹窗显示
    const [tileData, setTileData] = useState([]); // 页面初始化数据
    const [visible, setVisible] = useState(false); // 弹窗
    const [flag, setFlag] = useState(0); // 状态更新
    const [type, setType] = useState('add'); // 弹窗类型
    const [formObj, setFormObj] = useState({});


    const onSubmit = prop => {
        setVisible(false);
    };
    const delConfirm = (record) => {
        console.log('record', record)
    }
    const handleAdd = () => {
        setType('schemeAdd');
        setVisible(true);
    }
    useEffect(() => {
        renderTile();
    }, [visible, flag]);
    // 获取瓦片数据配置数据
    const renderTile = () => {
        setTreeLoading(true);
        GetAllConfig({
            terminalType: 'scheme',
            isBaseMap: false
        }).then(
            res => {
                if (res && res.Result.length > 0) {
                    setTreeLoading(false);
                    setTileData(res.Result);
                } else {
                    setTreeLoading(false);

                }
            }
        )
    };

    //增加瓦片
    const addTile = (item) => {
        console.log('item', item);
        setFormObj(item);
        setType('add');
        setVisible(true);
    }
    //删除方案
    const deleteTile = (item) => {
        deleteConfig({
            schemename: item.schemename,
            terminalType: 'scheme',
            isBaseMap: false
        }).then(res => {
            if (res.IsSuccess) {
                notification.success({
                    message: '提示',
                    duration: 3,
                    description: '方案删除成功',
                });
                setFlag(flag + 1)
            }
            else {
                notification.error({
                    message: '提示',
                    duration: 3,
                    description: '方案删除失败',
                });
            }
        })
    }
    //删除瓦片
    const deletebaseMap = (item,baseMapItem) => {
        unbindSchemeBaseMap({ schemename:item.schemename,basemapName: baseMapItem}).then(res=>{
            if (res.IsSuccess) {
                notification.success({
                    message: '提示',
                    duration: 3,
                    description: '底图删除成功',
                });
                setFlag(flag + 1)
            }
            else {
                notification.error({
                    message: '提示',
                    duration: 3,
                    description: '底图删除失败',
                });
            }
        })
    }
    return (
        <>
            <div style={{ width: 'calc(100vw - 265px)' }}>
                <div className={styles.tileBtn}>
                    <Button type="primary" onClick={() => {
                        handleAdd();
                    }} >
                        新增
                </Button>
                </div>
                <Row>
                    {tileData && tileData.length ?
                        tileData.map((item, index) => {
                            return <Col key={index} span={5} style={{ marginBottom: '1rem' }}> <Card title={<div><span className={styles.schemeName}>方案名</span>{item.schemename}</div>} extra={<a href="#">
                                <Popconfirm
                                    title="是否删除该方案？"
                                    okText="确认"
                                    cancelText="取消"
                                    onConfirm={() => {
                                        deleteTile(item);
                                    }}
                                >
                                    <CloseOutlined />
                                </Popconfirm> </a>} style={{ width: 300 }}>
                                <p><span className={styles.schemeName}>矢量</span>  {item.servicename}</p>
                                <div className={styles.schemeItem}><span className={styles.schemeName}>瓦片</span>
                                    <Button className={styles.schemeBtn} onClick={() => addTile(item)}> <PlusOutlined />添加瓦片</Button>
                                </div>
                                <div style={{ overflowY: 'scroll',height:'5.5rem' }}>
                                {item.baseMap && item.baseMap.length ? item.baseMap.map((baseMapItem, baseindex) => {
                                    return <div key={baseindex} className={styles.mapItem} >
                                        <div className={classnames({
                                            [styles.defaultTile]: true,
                                            [styles.activeTile]: baseindex == item.defaultBaseMap,
                                        })}>默认</div>
                                        <div className={styles.mapText}>{baseMapItem}</div>
                                        <div className={styles.mapIcon}>
                                            <Popconfirm
                                                title="是否删除该底图？"
                                                okText="确认"
                                                cancelText="取消"
                                                onConfirm={() => {
                                                    deletebaseMap(item,baseMapItem);
                                                }}
                                            >
                                                <CloseOutlined />
                                            </Popconfirm>  </div>
                                    </div>
                                }) : ''}
                                </div>
                            </Card>
                            </Col>
                        }) : ''}
                </Row >
                <AddModal
                    visible={visible}
                    onCancel={() => setVisible(false)}
                    callBackSubmit={onSubmit}
                    type={type}
                    formObj={formObj}
                />
            </div>
        </>
    )
}
export default VectorData